@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 
@@ -27,7 +27,6 @@
 #else
 #include <glib/gi18n.h>
 #endif
-#include <libgnomeui/gnome-window-icon.h>
 #include "dialog.h"
 #include "properties.h"
 
@@ -66,7 +65,7 @@ switch_page (GtkWidget *w, GtkNotebookPage *page, gint num, GtkHTMLEditPropertie
 		pd = (PageData *) g_list_nth (d->page_data, num)->data;
 		if (pd) {
 			gchar *title;
-			title = g_strconcat (d->title, ": ", pd->name, NULL);
+			title = g_strconcat (d->title, " ", pd->name, NULL);
 			gtk_window_set_title (GTK_WINDOW (d->dialog), title);
 			g_free (title);
 		}
@@ -91,18 +90,16 @@ dialog_response (GtkDialog *dialog, gint response_id, GtkHTMLEditPropertiesDialo
 }
 
 GtkHTMLEditPropertiesDialog *
-gtk_html_edit_properties_dialog_new (GtkHTMLControlData *cd, gchar *title, gchar *icon_path)
+gtk_html_edit_properties_dialog_new (GtkHTMLControlData *cd, gchar *title, gchar *icon_name)
 {
 	GtkHTMLEditPropertiesDialog *d = g_new (GtkHTMLEditPropertiesDialog, 1);
 	GtkWidget *vbox;
-	GtkWindow *parent;
 
 	d->page_data      = NULL;
 	d->title          = g_strdup (title);
 	d->control_data   = cd;
-	parent = get_parent_window (GTK_WIDGET (cd->html));
 
-	d->dialog = gtk_dialog_new_with_buttons (title, parent, 0,
+	d->dialog = gtk_dialog_new_with_buttons (title, NULL, 0,
 						 GTK_STOCK_HELP, GTK_RESPONSE_HELP,
 						 GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL,
 						 NULL);
@@ -122,7 +119,7 @@ gtk_html_edit_properties_dialog_new (GtkHTMLControlData *cd, gchar *title, gchar
 
 	g_signal_connect (d->dialog, "response", G_CALLBACK (dialog_response), d);
 
-	gnome_window_icon_set_from_file (GTK_WINDOW (d->dialog), icon_path);
+	gtk_window_set_icon_name (GTK_WINDOW (d->dialog), icon_name);
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (d->dialog), 0, FALSE);
 	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (d->dialog)->vbox), 6);
 
